diff PalanthirServer/ServerIndex.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children
line wrap: on
line diff
--- a/PalanthirServer/ServerIndex.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/ServerIndex.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "ServerIndex.h"
 
-using namespace Palantir;
+using namespace Palanthir;
 
 #ifndef NOMINMAX
 #define NOMINMAX
@@ -36,7 +36,7 @@
 #include <boost/lexical_cast.hpp>
 #include <stdio.h>
 
-namespace Palantir
+namespace Palanthir
 {
   namespace Internals
   {
@@ -109,7 +109,7 @@
         case 3:
           return "series";
         default:
-          throw PalantirException(ErrorCode_InternalError);
+          throw PalanthirException(ErrorCode_InternalError);
         }
       }
 
@@ -526,7 +526,7 @@
       return StoreStatus_Success;
       //t.Rollback();
     }
-    catch (PalantirException& e)
+    catch (PalanthirException& e)
     {
       std::cout << "EXCEPT2 [" << e.What() << "]" << " " << db_.GetErrorMessage() << std::endl;  
     }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium